# MeanReversionUtilities
Python Mean Reversion Utilities

Includes:

Maximum Likelihood OU calibration
- analytic (assumes identical timespace)
- numerical (allows for non uniform time sample, but might have problems with intraday)

Finds all mean reverting signals from multiple time series

Plotting multiple time series

